@@ -419,6 +419,28 @@ docker run -d --network=client-net --add-host=host.docker.internal:host-gateway
 #start memcache Container
 docker run -d --network=client-net --add-host=host.docker.internal:host-gateway -p 11211:11211  --restart unless-stopped --name memcache repo.anhonesthost.net/cloud-hosting-platform/cmc:latest
 
+# Set up password encryption
+echo ""
+echo "Setting up password encryption..."
+echo "================================="
+
+# Generate encryption key for password storage
+KEY_FILE="/etc/whp/encryption.key"
+if [ ! -f "$KEY_FILE" ]; then
+    mkdir -p /etc/whp
+    NEW_KEY=$(openssl rand -base64 32)
+    echo "$NEW_KEY" > "$KEY_FILE"
+    chmod 600 "$KEY_FILE"
+    chown root:root "$KEY_FILE"
+    echo "✓ Encryption key generated: $KEY_FILE"
+    echo ""
+    echo "⚠️  IMPORTANT: Save this encryption key securely!"
+    echo "📋 Key: $NEW_KEY"
+    echo ""
+else
+    echo "✓ Encryption key already exists"
+fi
+
 # Final verification
 echo ""
 echo "Performing final system verification..."
@@ -581,7 +603,15 @@ echo "✓ Terminal service installed and started successfully"
 echo "✓ WebSocket Terminal Server configured"
 cd /root/whp
 
-echo "Setup completed!"
+echo ""
+echo "🎉 Setup completed!"
+echo ""
+echo "⚠️  IMPORTANT SECURITY NOTES:"
+echo "   1. Save the encryption key from /etc/whp/encryption.key"
+echo "   2. Store server settings securely"
+echo "   3. Update DNS records for your domains"
+echo ""
+echo "Password encryption is enabled by default for all user passwords."
 echo ""
 echo "Access your control panel at: http://your-server-ip:8080"
 echo "Default login uses system PAM authentication"
